@@ -1,8 +1,11 @@
+from contextlib import contextmanager
 import datetime
+import time
 from django.conf import settings
 from django.utils.importlib import import_module
 
-from app_metrics.models import Metric, MetricSet, MetricItem
+from app_metrics.exceptions import InvalidMetricsBackend, TimerError
+from app_metrics.models import Metric, MetricSet
 
 def get_backend():
      return getattr(settings, 'APP_METRICS_BACKEND', 'app_metrics.backends.db')
@@ -73,12 +76,8 @@ def get_or_create_metric(name, slug):
     metric, created = Metric.objects.get_or_create(name=name, slug=slug)
     return metric
 
-class InvalidMetricsBackend(Exception): pass
-class MetricError(Exception): pass
-
-def metric(slug, num=1, **kwargs):
-    """ Increment a metric """
 
+def import_backend():
     backend_string = get_backend()
 
     # Attempt to import the backend
@@ -87,11 +86,95 @@ def metric(slug, num=1, **kwargs):
     except:
         raise InvalidMetricsBackend("Could not load '%s' as a backend" % backend_string )
 
+    return backend
+
+
+def metric(slug, num=1, **kwargs):
+    """ Increment a metric """
+    backend = import_backend()
+
     try:
         backend.metric(slug, num, **kwargs)
     except Metric.DoesNotExist:
         create_metric(slug=slug, name='Autocreated Metric')
 
+
+class Timer(object):
+    """
+    An object for manually controlling timing. Useful in situations where the
+    ``timing`` context manager will not work.
+
+    Usage::
+
+        timer = Timer()
+        timer.start()
+
+        # Do some stuff.
+
+        timer.stop()
+
+        # Returns a float of how many seconds the logic took.
+        timer.elapsed()
+
+        # Stores the float of how many seconds the logic took.
+        timer.store()
+
+    """
+    def __init__(self):
+        self._start = None
+        self._elapsed = None
+
+    def timestamp(self):
+        return time.time()
+
+    def start(self):
+        if self._start is not None:
+            raise TimerError("You have already called '.start()' on this instance.")
+
+        self._start = time.time()
+
+    def stop(self):
+        if self._start is None:
+            raise TimerError("You must call '.start()' before calling '.stop()'.")
+
+        self._elapsed = time.time() - self._start
+        self._start = None
+
+    def elapsed(self):
+        if self._elapsed is None:
+            raise TimerError("You must call '.stop()' before trying to get the elapsed time.")
+
+        return self._elapsed
+
+    def store(self, slug):
+        backend = import_backend()
+        backend.timing(slug, self.elapsed())
+
+
+@contextmanager
+def timing(slug):
+    """
+    A context manager to recording how long some logic takes & sends it off to
+    the backend.
+
+    Usage::
+
+        with timing('create_event'):
+            # Your code here.
+            # For example, create the event & all the related data.
+            event = Event.objects.create(
+                title='Coffee break',
+                location='LPT',
+                when=datetime.datetime(2012, 5, 4, 14, 0, 0)
+            )
+    """
+    timer = Timer()
+    timer.start()
+    yield
+    timer.stop()
+    timer.store(slug)
+
+
 def week_for_date(date):
     return date - datetime.timedelta(days=date.weekday())
 
